﻿/*
Examples and Papers:
https://blogs.sas.com/content/graphicallyspeaking/2012/03/05/proportionally-sized-bubble-plots/
https://support.sas.com/resources/papers/proceedings13/309-2013.pdf
*/


/* Open the LISTING destination and assign the HTMLBLUE style to the graph */ 
** Simple Bubble Plot using Bubble Statement;
ods listing style=htmlblue;
ods graphics /reset=all width=6in height=4in imagename='one';
ods html;
title 'Bubble: Age by Height and Weight';
proc sgplot data=sashelp.class(where=(sex='F')) noautolegend;
  bubble x=height y=weight size=age / group=name datalabel=name 
    transparency=0.4 datalabelattrs=(size=2pt weight=bold);
  inset "Bubble size represents Age" / position=bottomright textattrs=(size=8pt);
  yaxis grid;
  xaxis grid;
run;
title;

** use an YAxistable with Bubble for individual students;
ods listing style=htmlblue;
ods graphics /reset=all width=6in height=4in imagename='two';
ods html;
title 'YAXISTABLE: Students by Height and Weight';
proc sgplot data=sashelp.class(where=(sex='F')) noautolegend;
  bubble x=height y=name size=weight / group=name datalabel=name 
    transparency=0.4 datalabelattrs=(size=4pt weight=bold);
  inset "Bubble size represents Weight" / position=bottomright textattrs=(size=8pt);
  yaxis grid;
  yaxistable  age height weight;
run;
title;

  ** Annotating name;
  ** make a format to associate names with colors;
  proc format;
    value $tcf 'Alice'='cx6F7EB3'
               'Barbara'='cxD05B5B'
               'Carol'='cx66A5A0'
               'Jane'='cxA9865B'
               'Janet'='cxB689CD'
               'Joyce'='cxBABC5C'
               'Judy'='cx94BDE1'
               'Louise'='cxCD7BA1'
               'Mary'= 'cxCF974B';
  run;

**adjust the labels, add more info with annotate;
data work.anno_f;
   set sashelp.class(where=(sex='F'));
   Drawspace='datavalue';
   Function='text';
   X1=height;
   Y1=weight;
    
   Label=catt(name,'~',put(age,2.),'~H:',put(height,4.1));
   if name in ('Janet' 'Alice') then do;
      y1 = weight+.75;
   end;
   else if name in ('Mary' 'Jane' )then do;
      y1 = weight -.75;
	  if name = 'Jane' then x1=height+2;
	  else if name = 'Mary' then x1 = height + 1;
   end;
   else if name in ('Barbara' 'Joyce' 'Louise') then do;
      x1=height+2;
	  if name = 'Joyce' then y1 = weight+1;
   end;
   Textcolor=put(name,$tcf.);
   Width=400;
   Widthunit='pixel';
   Anchor='right';
   Textweight='bold';
run;

ods graphics /reset=all width=6in height=4in imagename='three';

title 'Annotate: Age by Height and Weight';
proc sgplot data=sashelp.class(where=(sex='F')) noautolegend sganno=work.anno_f ;
  bubble x=height y=weight size=age / group=name  
    transparency=0.4 datalabelattrs=(size=2pt weight=bold);
  inset "Bubble size represents Age" / position=bottomright textattrs=(size=8pt);
  yaxis grid;
  xaxis grid;
run;
